@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-
 r"""Module containing the notebook gatherer and hack of flake8.
+
 This is the main implementation of ``flake8_nb``, it relies on
 overwriting ``flake8`` 's CLI default options, searching and parsing
 ``*.ipynb`` files and injecting the parsed files, during the loading
@@ -10,15 +9,21 @@ of the CLI argv and config of ``flake8``.
 import logging
 import os
 import sys
-from typing import Callable, List, Optional, Tuple
+from typing import Callable
+from typing import List
+from typing import Optional
+from typing import Tuple
 
-from flake8 import defaults, utils
-import flake8
+from flake8 import __version__ as flake_version
+from flake8 import defaults
+from flake8 import utils
 from flake8.main.application import Application
-from flake8.options import aggregator, config
+from flake8.options import aggregator
+from flake8.options import config
 from flake8.utils import matches_filename
 
-from .. import FLAKE8_VERSION_TUPLE, __version__
+from .. import FLAKE8_VERSION_TUPLE
+from .. import __version__
 from ..parsers.notebook_parsers import NotebookParser
 
 LOG = logging.getLogger(__name__)
@@ -27,9 +32,10 @@ LOG = logging.getLogger(__name__)
 def get_notebooks_from_args(
     args: List[str], exclude: List[str] = ["*.tox/*", "*.ipynb_checkpoints*"]
 ) -> Tuple[List[str], List[str]]:
-    """
-    Extracts the absolute paths to notebooks from current director or
-    the to the CLI passes files/folder and return the as list.
+    """Extract the absolute paths to notebooks.
+
+    The paths are relative to the current directory or
+    to the CLI passes files/folder and returned as list.
 
     Parameters
     ----------
@@ -45,11 +51,28 @@ def get_notebooks_from_args(
         List of found notebooks absolute paths.
     """
 
-    def is_notebook(filename: str, nb_list: List, root="."):
-        filename = os.path.abspath(os.path.join(root, filename))
-        if os.path.isfile(filename) and filename.endswith(".ipynb"):
-            nb_list.append(os.path.normcase(filename))
+    def is_notebook(file_path: str, nb_list: List[str], root=".") -> bool:
+        """Check if a file is a notebook and appends it to nb_list if it is.
+
+        Parameters
+        ----------
+        filename : str
+            File to check if it is a notebook
+        nb_list : List[str]
+            List of notebooks
+        root : str, optional
+            Root directory, by default "."
+
+        Returns
+        -------
+        bool
+            Whether the given file is a notebook
+        """
+        file_path = os.path.abspath(os.path.join(root, file_path))
+        if os.path.isfile(file_path) and file_path.endswith(".ipynb"):
+            nb_list.append(os.path.normcase(file_path))
             return True
+        return False
 
     nb_list: List[str] = []
     if not args:
@@ -70,24 +93,56 @@ def get_notebooks_from_args(
 
 
 def hack_option_manager_generate_versions(generate_versions: Callable) -> Callable:
-    def hacked_generate_versions(*args, **kwargs):
+    """Closure to prepend the flake8 version to option_manager.generate_versions .
+
+    Parameters
+    ----------
+    generate_versions : Callable
+        option_manager.generate_versions of flake8.options.manager.OptionManager
+
+    Returns
+    -------
+    Callable
+        hacked_generate_versions
+    """
+
+    def hacked_generate_versions(*args, **kwargs) -> str:
+        """Inner wrapper around option_manager.generate_versions .
+
+        Returns
+        -------
+        str
+            Plugin versions string containing flake8
+        """
         original_output = generate_versions(*args, **kwargs)
         format_str = "%(name)s: %(version)s"
         join_on = ", "
-        additional_output = format_str % {"name": "flake8", "version": flake8.__version__}
+        additional_output = format_str % {
+            "name": "flake8",
+            "version": flake_version,
+        }
         return f"{additional_output}{join_on}{original_output}"
 
     return hacked_generate_versions
 
 
 class Flake8NbApplication(Application):
-    r"""
-    Subclass of ```flake8.main.application.Application``, with
-    overwritten default options and an injection of intermediate parsed
+    r"""Subclass of ``flake8.main.application.Application``.
+
+    It overwrites the default options and an injection of intermediate parsed
     ``*.ipynb`` files to be checked.
     """
 
     def __init__(self, program="flake8_nb", version=__version__):
+        """Hacked initialization of flake8.Application.
+
+        Parameters
+        ----------
+        program : str, optional
+            Application name, by default "flake8_nb"
+        version : [type], optional
+            Application version, by default __version__
+        """
         super().__init__(program, version)
         self.hack_flake8_program_and_version(program, version)
         self.hack_options()
@@ -101,15 +156,15 @@ class Flake8NbApplication(Application):
         self.option_manager.generate_versions = hack_option_manager_generate_versions(
             self.option_manager.generate_versions
         )
-        if FLAKE8_VERSION_TUPLE > (3, 7, 9):
+        if FLAKE8_VERSION_TUPLE < (3, 8, 0):
             self.parse_configuration_and_cli = (  # type: ignore
-                self.parse_configuration_and_cli_nightly
+                self.parse_configuration_and_cli_legacy
             )
 
     def hack_flake8_program_and_version(self, program: str, version: str) -> None:
-        """
-        Another hack to overwrite the program name and version of flake8,
-        which is hard coded at creation of `self.option_manager`.
+        """Hack to overwrite the program name and version of flake8.
+
+        This is needed because those values are hard coded at creation of `self.option_manager`.
 
         Parameters
         ----------
@@ -126,8 +181,9 @@ class Flake8NbApplication(Application):
         self.option_manager.version = version
 
     def set_flake8_option(self, long_option_name: str, *args, **kwargs) -> None:
-        """
-        First deletes and than readds an option to `flake8`'s cli options, if it was present.
+        """Overwrite flake8 options.
+
+        First deletes and than reads an option to `flake8`'s cli options, if it was present.
         If the option wasn't present, it just adds it.
 
 
@@ -155,9 +211,7 @@ class Flake8NbApplication(Application):
         self.option_manager.add_option(long_option_name, *args, **kwargs)
 
     def hack_options(self) -> None:
-        """
-        Overwrites ``flake8``'s default options, with ``flake8_nb`` defaults.
-        """
+        """Overwrite ``flake8``'s default options, with ``flake8_nb`` defaults."""
         self.set_flake8_option(
             "--format",
             metavar="format",
@@ -186,7 +240,8 @@ class Flake8NbApplication(Application):
 
     @staticmethod
     def hack_args(args: List[str], exclude: List[str]) -> List[str]:
-        r"""
+        r"""Update args with ``*.ipynb`` files.
+
         Checks the passed args if ``*.ipynb`` can be found and
         appends intermediate parsed files to the list of files,
         which should be checked.
@@ -203,14 +258,17 @@ class Flake8NbApplication(Application):
         List[str]
             The original args + intermediate parsed ``*.ipynb`` files.
         """
-
         args, nb_list = get_notebooks_from_args(args, exclude=exclude)
         notebook_parser = NotebookParser(nb_list)
         return args + notebook_parser.intermediate_py_file_paths
 
-    def parse_configuration_and_cli(self, argv: Optional[List[str]] = None) -> None:
-        """
-        Compat version of self.parse_configuration_and_cli to work with flake8 >=3.7.0,<= 3.7.9
+    def parse_configuration_and_cli_legacy(
+        self,
+        argv: Optional[List[str]] = None,
+    ) -> None:
+        """Compat version of self.parse_configuration_and_cli to work with flake8 >=3.7.0,<= 3.7.9 .
+
+        See https://gitlab.com/pycqa/flake8/blob/master/src/flake8/main/application.py#L194
 
         Parse configuration files and the CLI options.
 
@@ -237,14 +295,10 @@ class Flake8NbApplication(Application):
         self.check_plugins.provide_options(self.option_manager, self.options, self.args)
         self.formatting_plugins.provide_options(self.option_manager, self.options, self.args)
 
-    def parse_configuration_and_cli_nightly(
+    def parse_configuration_and_cli(
         self, config_finder: config.ConfigFileFinder, argv: List[str]
     ) -> None:
-        """
-        Compat version of self.parse_configuration_and_cli to work with flake8 > 3.7.9 and master
-        https://gitlab.com/pycqa/flake8/blob/master/src/flake8/main/application.py#L194
-
-        Parse configuration files and the CLI options.
+        """Parse configuration files and the CLI options.
 
         :param config.ConfigFileFinder config_finder:
             The finder for finding and reading configuration files.
@@ -252,7 +306,9 @@ class Flake8NbApplication(Application):
             Command-line arguments passed in directly.
         """
         self.options, self.args = aggregator.aggregate_options(
-            self.option_manager, config_finder, argv,
+            self.option_manager,
+            config_finder,
+            argv,
         )
 
         self.args = self.hack_args(self.args, self.options.exclude)
@@ -277,7 +333,8 @@ class Flake8NbApplication(Application):
         if self.options.keep_parsed_notebooks:
             temp_path = NotebookParser.temp_path
             print(
-                f"The parsed notebooks, are still present at:\n\t{temp_path}", file=sys.stderr,
+                f"The parsed notebooks, are still present at:\n\t{temp_path}",
+                file=sys.stderr,
             )
         else:
             NotebookParser.clean_up()
