@@ -1,12 +1,13 @@
-# -*- coding: utf-8 -*-
-
 """Module containing parsers for notebook cells.
-This also inclues parsers for the cell and inline tags.
-It heavily utilizes the mutability of lists."""
+
+This also includes parsers for the cell and inline tags.
+It heavily utilizes the mutability of lists.
+"""
 
 import re
 import warnings
-from typing import Dict, List
+from typing import Dict
+from typing import List
 
 FLAKE8_TAG_PATTERN = re.compile(
     r"^flake8-noqa-(cell-(?P<cell_rules>(\w+\d+-?)+)"
@@ -32,14 +33,21 @@ FLAKE8_NOQA_INLINE_REPLACE_PATTERN = re.compile(
 
 
 class InvalidFlake8TagWarning(UserWarning):
-    """
-    Warning which is thrown, when a cell tag starts with
-    'flake8-noqa-' but doesn't match the correct pattern
-    needed for cell tags. This is used to show users that
-    they have a typo in their tags.
+    """Warning thrown when a tag is badly formatted.
+
+    When a cell tag starts with 'flake8-noqa-' but doesn't
+    match the correct pattern needed for cell tags.
+    This is used to show users that they have a typo in their tags.
     """
 
-    def __init__(self, flake8_tag, *args, **kwargs):
+    def __init__(self, flake8_tag: str, *args, **kwargs):
+        """Create InvalidFlake8TagWarning.
+
+        Parameters
+        ----------
+        flake8_tag : str
+            Used improperly formatted flake8-nb tag
+        """
         super().__init__(
             "flake8-noqa-line/cell-tags should be of form "
             "'flake8-noqa-cell-<rule1>-<rule2>'|'flake8-noqa-cell'/"
@@ -49,8 +57,7 @@ class InvalidFlake8TagWarning(UserWarning):
 
 
 def extract_flake8_tags(notebook_cell: Dict) -> List[str]:
-    """
-    Exctracts all tag that start with 'flake8-noqa-' from a cell.
+    """Extract all tag that start with 'flake8-noqa-' from a cell.
 
     Parameters
     ----------
@@ -70,8 +77,7 @@ def extract_flake8_tags(notebook_cell: Dict) -> List[str]:
 
 
 def extract_flake8_inline_tags(notebook_cell: Dict) -> List[str]:
-    """
-    Extracts flake8-tags which were used as comment in a cell.
+    """Extract flake8-tags which were used as comment in a cell.
 
     Parameters
     ----------
@@ -96,9 +102,7 @@ def extract_flake8_inline_tags(notebook_cell: Dict) -> List[str]:
 
 
 def extract_inline_flake8_noqa(source_line: str) -> List[str]:
-    """
-    Extracts flake8 noqa rules from normal flake8 comments and
-    returns the as list.
+    """Extract flake8 noqa rules from normal flake8 comments .
 
     Parameters
     ----------
@@ -122,8 +126,8 @@ def extract_inline_flake8_noqa(source_line: str) -> List[str]:
 
 
 def flake8_tag_to_rules_dict(flake8_tag: str) -> Dict[str, List[str]]:
-    """
-    Parses a flake8 tag to a ``rules_dict``.
+    """Parse a flake8 tag to a ``rules_dict``.
+
     ``rules_dict`` contains lists of rules, depending on if the
     tag is a cell or a line tag.
 
@@ -162,11 +166,9 @@ def flake8_tag_to_rules_dict(flake8_tag: str) -> Dict[str, List[str]]:
     return {}
 
 
-def update_rules_dict(
-    total_rules_dict: Dict[str, List], new_rules_dict: Dict[str, List]
-) -> None:
-    """
-    Updates the rules dict ``total_rules_dict`` with ``new_rules_dict``.
+def update_rules_dict(total_rules_dict: Dict[str, List], new_rules_dict: Dict[str, List]) -> None:
+    """Update the rules dict ``total_rules_dict`` with ``new_rules_dict``.
+
     If any entry of a key is 'noqa' (ignore all), the rules will be
     set to be only 'noqa'.
 
@@ -195,8 +197,8 @@ def update_rules_dict(
 
 
 def get_flake8_rules_dict(notebook_cell: Dict) -> Dict[str, List]:
-    """
-    Parses all flake8 tags of a cell to a ``rules_dict``.
+    """Parse all flake8 tags of a cell to a ``rules_dict``.
+
     ``rules_dict`` contains lists of rules, depending on if the
     tag is a cell or a line tag.
 
@@ -225,9 +227,9 @@ def get_flake8_rules_dict(notebook_cell: Dict) -> Dict[str, List]:
 
 
 def generate_rules_list(source_index: int, rules_dict: Dict[str, List]) -> List[str]:
-    """
-    Generates a List of rules from ``rules_dict``, which should be
-    applied to the line at ``source_index``.
+    """Generate a List of rules from ``rules_dict``.
+
+    This list should be applied to the line at ``source_index``.
 
     Parameters
     ----------
@@ -252,8 +254,8 @@ def generate_rules_list(source_index: int, rules_dict: Dict[str, List]) -> List[
 
 
 def update_inline_flake8_noqa(source_line: str, rules_list: List[str]) -> str:
-    """
-    Updates ``source_line`` with flake8 noqa comments.
+    """Update ``source_line`` with flake8 noqa comments.
+
     This is done extraction flake8-tags as well as inline flake8
     comments.
 
@@ -277,9 +279,7 @@ def update_inline_flake8_noqa(source_line: str, rules_list: List[str]) -> str:
     source_line = source_line.rstrip("\n")
     if inline_flake8_noqa:
         rules_list = list(set(inline_flake8_noqa + rules_list))
-        source_line = re.sub(
-            FLAKE8_NOQA_INLINE_REPLACE_PATTERN, r"\g<source_code>", source_line
-        )
+        source_line = re.sub(FLAKE8_NOQA_INLINE_REPLACE_PATTERN, r"\g<source_code>", source_line)
     rules_list = sorted(rules_list)
     if "noqa" in rules_list:
         noqa_str = ""
@@ -292,9 +292,9 @@ def update_inline_flake8_noqa(source_line: str, rules_list: List[str]) -> str:
 
 
 def notebook_cell_to_intermediate_dict(notebook_cell: Dict) -> Dict:
-    r"""
-    Parses ``notebook_cell`` to a dict which can later be written to a
-    intermediate_py_file.
+    r"""Parse ``notebook_cell`` to a dict.
+
+    That dict can later be written to a intermediate_py_file.
 
     Parameters
     ----------
