@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
 import os
 from typing import Iterator
 
 import pytest
 
-from flake8_nb.parsers.notebook_parsers import InvalidNotebookWarning, NotebookParser
+from flake8_nb.parsers.notebook_parsers import InvalidNotebookWarning
+from flake8_nb.parsers.notebook_parsers import NotebookParser
 
 from .parsers.test_notebook_parsers import TEST_NOTEBOOK_BASE_PATH
 
@@ -17,9 +17,7 @@ def notebook_parser() -> Iterator[NotebookParser]:
         "notebook_with_out_flake8_tags.ipynb",
         "notebook_with_out_ipython_magic.ipynb",
     ]
-    notebook_paths = [
-        os.path.join(TEST_NOTEBOOK_BASE_PATH, notebook) for notebook in notebooks
-    ]
+    notebook_paths = [os.path.join(TEST_NOTEBOOK_BASE_PATH, notebook) for notebook in notebooks]
     with pytest.warns(InvalidNotebookWarning):
         parser_instance = NotebookParser(notebook_paths)
     yield parser_instance
